# frozen_string_literal: true
require 'httparty'
require 'active_support'
require 'active_support/core_ext/integer'
require 'active_support/core_ext/string'

class APIWrapper
  EKEY = <<~EKEY
  R6S3-rUOOByRSSKoY1EW1dlxoqYZ8vn9bH0BzvlaaY9_KZ8SoinkGJ9URxzG
  wDvugK7lIJS9TcoC2OoAtb8VN-0T2gqaGDkRC1so_C3oe_K8JBW68HjPm3jfPpDbWO4t
  EKEY
  SESSION='ipbm5c99jaf7rsf179jihn3ti1'
  DAYS = 7
  DATUM = 'LAT'

  # From what I can tell, the ekey is ekey is verified against the cookie
  INPUTS = %i(lat lon)

  include HTTParty

  attr_accessor *INPUTS
  attr_reader :res

  base_uri 'www.worldtides.info'

  def initialize(lat:, lon:)
    @lat = lat
    @lon = lon
    @res = make_request
    raise "Failed with #{@res['status']}" unless @res['status'] == 200
  end

  def highs_and_lows
    @highs_and_lows ||= begin
      @res['extremes'].map do |record|
        {
          date: record['date'].to_time.to_s(:short),
          type: record['type'].downcase,
          height: record['height']
        }
      end
    end
  end

  def highs_and_lows_csv(output_file)
    File.open("#{output_file}.csv", 'w') do |f|
      f << CSV.generate do |csv|
        csv << highs_and_lows.first.keys
        highs_and_lows.each { |h_a_l| csv << h_a_l.values }
      end
    end
  end

  private

  def make_request
    self.class.get('/api', query: query, headers: headers)
  end

  def query
    {
      datum: DATUM,
      extremes: true,
      start: DAYS.days.ago.to_i,
      length: DAYS.days,
      step: 1800,
      lat: lat,
      lon: lon,
      stationDistance: 100,
      ekey: EKEY.strip
    }
  end

  def headers
    {
      'Cookie' => CookieHash.new.add_cookies(
        { WorldTidesInfoSession: SESSION }
      ).to_cookie_string
    }
  end
end
