# frozen_string_literal: true

require 'thor'

module WorldTides
  # Handle the application command line parsing
  # and the dispatch to various command objects
  #
  # @api public
  class CLI < Thor
    # Error raised by this runner
    Error = Class.new(StandardError)

    desc 'version', 'world_tides version'
    def version
      require_relative 'version'
      puts "v#{WorldTides::VERSION}"
    end
    map %w(--version -v) => :version

    desc 'fetch FILENAME LON LAT', 'Fetches the last 7 days of extremes data'
    method_option :help, aliases: '-h', type: :boolean,
                         desc: 'Display usage information'
    def fetch(filename, lon, lat)
      if options[:help]
        invoke :help, ['fetch']
      else
        require_relative 'commands/fetch'
        WorldTides::Commands::Fetch.new(filename, lon, lat, options).execute
      end
    end
  end
end
